@@ -58,7 +58,7 @@ class Robot:
         return self.post_(type_, data_)
 
 
-
-a = Robot(url="http://127.0.0.1:7777/DaenWxHook/httpapi/", wxid="wxid_at1vbqt6zgg922")
-bbb=a.get_friend_list()
-print(bbb)
+#
+# a = Robot(url="http://127.0.0.1:7777/DaenWxHook/httpapi/", wxid="wxid_at1vbqt6zgg922")
+# bbb=a.get_friend_list()
+# print(bbb)
